@@ -793,7 +793,7 @@ static void evaluateExpression(double *myLeft, char *binaryOperation)
 	while (!emptyExpression()) {
 		myRight = *myLeft;
 		getPreviousExpressionPart(myLeft, binaryOperation);
-		if (binaryOperation != '\0')
+		if (binaryOperation != NULL)
 			*myLeft = evaluateDouble(*myLeft, *binaryOperation,
 				myRight);
 		else
@@ -835,6 +835,7 @@ parse(double input, Boolean numeral, char newOperation)
 		if (negateNext) {
 			negateNext = False;
 			right = -input;
+			pendingOperation = '\0';
 		} else {
 			right = input;
 		}
