@@ -228,7 +228,7 @@ SetAllColors(AbacusWidget w, Boolean init)
 		XtReleaseGC((Widget) w, w->abacusDemo.inverseGC);
 	w->abacusDemo.inverseGC = XtGetGC((Widget) w, valueMask, &values);
 	if (w->abacusDemo.fontInfo)
-                XSetFont(XtDisplay(w), w->abacusDemo.foregroundGC,
+                (void) XSetFont(XtDisplay(w), w->abacusDemo.foregroundGC,
 			w->abacusDemo.fontInfo->fid);
 }
 
@@ -670,7 +670,7 @@ DestroyAbacusDemo(Widget old)
 	XtReleaseGC(old, w->abacusDemo.foregroundGC);
 	XtReleaseGC(old, w->abacusDemo.inverseGC);
 	XtRemoveCallbacks(old, XtNselectCallback, w->abacus.select);
-	XFreeFont(XtDisplay(w), w->abacusDemo.fontInfo);
+	(void) XFreeFont(XtDisplay(w), w->abacusDemo.fontInfo);
 }
 
 #else
