@@ -51,7 +51,13 @@ is no recorded usage of a larger Roman numeral in Roman times.
 An older notation for Roman numerals was represented thus:
 ( = C, I) = D, (I) = M, I)) = v, ((I)) = x, I))) = l, (((I))) = c,
  _
-|X| = m */
+|X| = m
+Fractions
+12 ounces (uncia) in a as
+S = 1/2 ounce
+) = 1/4 ounce
+Z = 1/3 ounce
+*/
 };
 
 #ifdef HAVE_LONG_LONG
@@ -133,7 +139,8 @@ int2String(char *buf, LONG number, int base, Boolean negative)
 }
 
 static int
-flt2String(char *buf, LONG number, int abacusBase, int base, int places, int decimalPosition)
+flt2String(char *buf, LONG number, int abacusBase, int base, int places,
+		int decimalPosition)
 {
 	int position = 0, digit;
 	double mult = 1.0 / base;
@@ -209,13 +216,12 @@ squareroot(int i)
 }
 
 void
-dividePieces(char * buf, int base, int pieces, int mult, int places)
+dividePieces(char *buf, int base, int pieces, int mult, int places)
 {
 	int position, digit, inter;
 
 	digit = mult / pieces;
 	inter = mult % pieces;
-	/* This works because digit should never be greater than base here */
 	(void) sprintf(buf, "%1d.", digit);
 	for (position = 2; position < places;) {
 		digit = (inter * base) / pieces;
@@ -228,6 +234,40 @@ dividePieces(char * buf, int base, int pieces, int mult, int places)
 	buf[position] = '\0';
 }
 
+void
+shiftDecimal(char *buf, char *aBuf, int shift, int place)
+{
+	int size = strlen(aBuf);
+	int loc = 0, i = 0;
+
+	while (aBuf[loc] != '.' && loc < size) {
+		buf[i] = aBuf[loc];
+		loc++;
+		i++;
+	}
+	buf[i] = aBuf[loc];
+	i++;
+	while (loc < place + 1) {
+		loc++;
+		buf[i] = aBuf[loc];
+		i++;
+	}	
+	if (shift > 0) {
+		/* shift right */
+		for (i = place + 2; i < shift + place + 2; i++)
+			buf[i] = '0';
+	} else {
+		/* shift left */
+		loc -= shift;
+	}
+	while (loc < size - 1) {
+		loc++;
+		buf[i] = aBuf[loc];
+		i++;
+	}
+	buf[i] = '\0';
+}
+
 /* 2nd grade math is hard */
 /* May disregard sign if different */
 void
@@ -307,10 +347,18 @@ addStrings(char *finalBuf, char *aBuf, char *bBuf, int base)
 		} else
 			(void) strcpy(finalBuf, bBuf);
 	}
+	i = strlen(finalBuf) - 1;
+	while (finalBuf[i] == '0' && finalBuf[i - 1] != '.')
+		i--;
+	finalBuf[i + 1] = '\0';
+
 }
 
 void
-convertString(char * buf, char * inbuf, int base, int displayBase, int decimalPosition)
+convertString(char * buf, char * inbuf, int base, int displayBase,
+		int decimalPosition,
+		int anomaly, int shiftAnomaly,
+		int anomalySq, int shiftAnomalySq)
 {
 	char fltbuf[256];
 	int i, last, place = -1, decimalPlace, decimalPointPlace;
@@ -340,8 +388,17 @@ convertString(char * buf, char * inbuf, int base, int displayBase, int decimalPo
 				char2Int(inbuf[i]));
 			place--;
 		} else {
-			intPart += (((LONG) power(base, place)) *
-				char2Int(inbuf[i]));
+			if (place >= shiftAnomaly && anomaly != 0) {
+				if (place >= shiftAnomalySq + shiftAnomaly && anomalySq != 0)
+					intPart += (((LONG) power(base, place - 2))) *
+						char2Int(inbuf[i]) * (base - anomaly) *
+						(base - anomalySq);
+				else
+					intPart += (((LONG) power(base, place - 1))) *
+						char2Int(inbuf[i]) * (base - anomaly);
+			} else
+				intPart += (((LONG) power(base, place)) *
+					char2Int(inbuf[i]));
 			place--;
 		}
 	}
