@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2006	David Albert Bagley, bagleyd@tux.org
 #
 #  Abacus demo and neat pointers from
 #  Copyright (c) 1991 - 1998	Luis Fernandes, elf@ee.ryerson.ca
@@ -62,7 +62,9 @@ extern void RomanNumeralsAbacus(AbacusWidget w);
 extern void SignAbacus(AbacusWidget w);
 extern void QuarterAbacus(AbacusWidget w);
 extern void QuarterPercentAbacus(AbacusWidget w);
-extern void VerticalAbacus(AbacusWidget w);
+extern void TwelfthAbacus(AbacusWidget w);
+extern void AnomalyAbacus(AbacusWidget w);
+extern void WatchAbacus(AbacusWidget w);
 extern void EnterAbacus(AbacusWidget w);
 extern void LeaveAbacus(AbacusWidget w);
 
@@ -119,12 +121,11 @@ extern AbacusClassRec abacusClassRec;
 #define BOTTOM 0
 #define CARRY 2	/* I guess it could be even more if you have a weird config
 		   also need a space to hold null (not included) */
-#define SPECIAL_QUARTERS 2 /* Quarters, QuarterPercents */
+#define SPECIAL_PIECES 2 /* Pieces, PiecePercents */
 
 /* Migrate to Locale */
 #define DECIMAL_SEPARATOR '.'
 #define GROUP_SEPARATOR ','
-#define GROUPING_SIZE 3
 
 #define MAXLENFORMAT 9
 
@@ -147,6 +148,7 @@ typedef struct _DeckPart {
 	int         spaces;	/* spaces between beads */
 	int         room;	/* spaces + number */
 	Position    height;
+	int         piece, piecePercent;
 } DeckPart;
 
 typedef struct _AbacusPart {
@@ -155,14 +157,16 @@ typedef struct _AbacusPart {
 	int         rails;	/* number of columns of beads */
 	int         decimalPosition, numDigits;
 	int         base, displayBase;	/* 10 usually */
+	int         shiftPercent, shiftAnomaly, shiftAnomalySq;
+	int         groupSize, anomaly, anomalySq;
 	int         delay, numSlices, mode;
 	int         deck, rail, number;
 	Position    width, midHeight, midBarY, railWidth;
 	Point       frameSize, beadSize;
 	Point       pos, delta, offset;
+	Boolean     sign, romanNumerals;
 	Boolean     mono, reverse, script, demo, focus, vertical, aux;
 	Boolean     versionOnly;
-	Boolean     sign, quarter, quarterPercent, romanNumerals;
 	Boolean     slot, diamond, sound;
 	char       *digits, *mathBuffer;
 	FILE       *fp;
@@ -216,12 +220,15 @@ extern char int2Char(int digit);
 
 extern void dividePieces(char * buf, int base, int pieces,
 	int mult, int places);
+extern void shiftDecimal(char *buf, char *aBuf, int shift, int place);
 extern void addStrings(char *finalBuf, char *buf, char *pieceBuf,
 	int base);
 extern void subStrings(char *finalBuf, char *buf, char *pieceBuf,
 	int base);
 extern void convertString(char * buf, char * inbuf,
-	int base, int displayBase, int decimalPosition);
+	int base, int displayBase, int decimalPosition,
+	int anomaly, int shiftAnomaly,
+	int anomalySq, int shiftAnomalySq);
 
 extern int sizeofRoman(int base, Boolean romanNumerals);
 extern int string2Roman(char *buf, char *inbuf, int base);
